<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>PianoPalette</name>
    <message>
        <location filename="../pianopalette.cpp" line="143"/>
        <location filename="../pianopalette.cpp" line="215"/>
        <location filename="../pianopalette.cpp" line="226"/>
        <location filename="../pianopalette.cpp" line="297"/>
        <location filename="../pianopalette.cpp" line="354"/>
        <location filename="../pianopalette.cpp" line="365"/>
        <source>N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="144"/>
        <location filename="../pianopalette.cpp" line="216"/>
        <location filename="../pianopalette.cpp" line="227"/>
        <location filename="../pianopalette.cpp" line="298"/>
        <location filename="../pianopalette.cpp" line="355"/>
        <location filename="../pianopalette.cpp" line="366"/>
        <source>#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="154"/>
        <location filename="../pianopalette.cpp" line="308"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="155"/>
        <location filename="../pianopalette.cpp" line="309"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="156"/>
        <location filename="../pianopalette.cpp" line="310"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="157"/>
        <location filename="../pianopalette.cpp" line="311"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="158"/>
        <location filename="../pianopalette.cpp" line="312"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="159"/>
        <location filename="../pianopalette.cpp" line="313"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="160"/>
        <location filename="../pianopalette.cpp" line="314"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="161"/>
        <location filename="../pianopalette.cpp" line="315"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="162"/>
        <location filename="../pianopalette.cpp" line="316"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="163"/>
        <location filename="../pianopalette.cpp" line="317"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="164"/>
        <location filename="../pianopalette.cpp" line="318"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="165"/>
        <location filename="../pianopalette.cpp" line="319"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="166"/>
        <location filename="../pianopalette.cpp" line="320"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="167"/>
        <location filename="../pianopalette.cpp" line="321"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="168"/>
        <location filename="../pianopalette.cpp" line="322"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="169"/>
        <location filename="../pianopalette.cpp" line="323"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="194"/>
        <location filename="../pianopalette.cpp" line="333"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="195"/>
        <location filename="../pianopalette.cpp" line="334"/>
        <source>C#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="196"/>
        <location filename="../pianopalette.cpp" line="335"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="197"/>
        <location filename="../pianopalette.cpp" line="336"/>
        <source>D#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="198"/>
        <location filename="../pianopalette.cpp" line="337"/>
        <source>E</source>
        <translation>E</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="199"/>
        <location filename="../pianopalette.cpp" line="338"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="200"/>
        <location filename="../pianopalette.cpp" line="339"/>
        <source>F#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="201"/>
        <location filename="../pianopalette.cpp" line="340"/>
        <source>G</source>
        <translation>G</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="202"/>
        <location filename="../pianopalette.cpp" line="341"/>
        <source>G#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="203"/>
        <location filename="../pianopalette.cpp" line="342"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="204"/>
        <location filename="../pianopalette.cpp" line="343"/>
        <source>A#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="205"/>
        <location filename="../pianopalette.cpp" line="344"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="228"/>
        <location filename="../pianopalette.cpp" line="367"/>
        <source>N*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="229"/>
        <location filename="../pianopalette.cpp" line="368"/>
        <source>#*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="241"/>
        <source>Single color highlight</source>
        <translation>单色高亮</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="242"/>
        <source>A single color to highlight all note events</source>
        <translation>用一种颜色高亮所有音符事件</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="246"/>
        <source>Two colors highlight</source>
        <translation>双色高亮</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="247"/>
        <source>One color to highlight natural notes and a different one for accidentals</source>
        <translation>一种颜色用于突出自然音，另一种颜色用于变化音</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="251"/>
        <source>MIDI Channels highlight</source>
        <translation>MIDI 通道高亮</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="252"/>
        <source>A different color to highlight each MIDI channel. Enable Omni mode in the MIDI IN connection</source>
        <translation>用不同颜色突出显示每个 MIDI 通道。在 MIDI 输入 连接中启用全通道模式</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="256"/>
        <source>Chromatic scale background</source>
        <translation>半音阶背景色</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="257"/>
        <location filename="../pianopalette.cpp" line="272"/>
        <source>One color for each note in the chromatic scale</source>
        <translation>半音阶中的每个音符都用一种颜色表示</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="261"/>
        <source>Keys background</source>
        <translation>琴键背景色</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="262"/>
        <source>One color for natural notes and another for accidentals</source>
        <translation>一种颜色用于自然音，另一种用于变化音</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="266"/>
        <source>Font foreground</source>
        <translation>字体前景色</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="267"/>
        <source>Colors for note names</source>
        <translation>用于音符名称的颜色</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="271"/>
        <source>Chromatic scale highlight</source>
        <translation>半音阶高亮</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::FluidSettingsDialog</name>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="14"/>
        <source>FluidSynth Driver Settings</source>
        <translation>FluidSynth 驱动设置</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="123"/>
        <source>Sample Rate:</source>
        <translation>采样率：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="106"/>
        <source>Period Size:</source>
        <translation>周期大小：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="159"/>
        <source># of Periods:</source>
        <translation>周期数量：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="39"/>
        <source>Audio Driver:</source>
        <translation>音频驱动：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="169"/>
        <source>Polyphony:</source>
        <translation>复音数：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="89"/>
        <source>FluidSynth Version:</source>
        <translation>FluidSynth 版本：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="69"/>
        <source>Sound Font:</source>
        <translation>音色库：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="116"/>
        <source>Initialization Status:</source>
        <translation>初始化状态：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="185"/>
        <source>Buffer Time:</source>
        <translation>缓冲时间：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="192"/>
        <source> ms</source>
        <translation> 毫秒</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="49"/>
        <source>Gain:</source>
        <translation>增益调节：</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="152"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="139"/>
        <source>Chorus</source>
        <translation>合唱（Chorus）</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="62"/>
        <source>Reverb</source>
        <translation>混响（Reverb）</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="144"/>
        <source>FluidSynth Initialized</source>
        <translation>FluidSynth 已初始化</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="144"/>
        <source>FluidSynth Initialization Failed</source>
        <translation>FluidSynth 初始化失败</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="207"/>
        <source>Ready</source>
        <translation>就绪</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="207"/>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="338"/>
        <source>Select SoundFont</source>
        <translation>选择音色库</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="338"/>
        <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
        <translation>音色库文件 (*.sf2 *.sf3 *.dls)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::MacSynthSettingsDialog</name>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="14"/>
        <source>macOS Synth Driver Settings</source>
        <translation>macOS Synth 驱动设置</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="56"/>
        <source>SoundFont:</source>
        <translation>音色库：</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="76"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="83"/>
        <source>Use Internal Reverb</source>
        <translation>使用内部混响</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="90"/>
        <source>Init. Status:</source>
        <translation>初始化状态：</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="69"/>
        <source>Default Apple DLS Sound Set</source>
        <translation>使用苹果 DLS 音效</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialized</source>
        <translation>DLS Synth 已初始化</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialization Failed</source>
        <translation>DLS Synth 初始化失败</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Ready</source>
        <translation>就绪</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>Select SoundFont</source>
        <translation>选择音色库</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>SoundFont Files (*.sf2 *.dls)</source>
        <translation>音色库文件 (*.sf2 *.dls)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::NetworkSettingsDialog</name>
    <message>
        <location filename="../networksettingsdialog.ui" line="14"/>
        <source>Network Driver Settings</source>
        <translation>网络驱动设置</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="33"/>
        <source>Init. Status:</source>
        <translation>初始化状态：</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="50"/>
        <source>Use IPv6</source>
        <translation>使用 IPv6</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="57"/>
        <source>Network Interface:</source>
        <translation>网络接口：</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="70"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialized</source>
        <translation>网络已初始化</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialization Failed</source>
        <translation>网络初始化失败</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="111"/>
        <location filename="../networksettingsdialog.cpp" line="174"/>
        <source>Any</source>
        <translation>任意</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Ready</source>
        <translation>就绪</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::PianoScene</name>
    <message>
        <location filename="../pianoscene.cpp" line="1258"/>
        <location filename="../pianoscene.cpp" line="1271"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1259"/>
        <source>C♯</source>
        <translation>C♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1260"/>
        <location filename="../pianoscene.cpp" line="1273"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1261"/>
        <source>D♯</source>
        <translation>D♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1262"/>
        <location filename="../pianoscene.cpp" line="1275"/>
        <source>E</source>
        <translation>E</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1263"/>
        <location filename="../pianoscene.cpp" line="1276"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1264"/>
        <source>F♯</source>
        <translation>F♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1265"/>
        <location filename="../pianoscene.cpp" line="1278"/>
        <source>G</source>
        <translation>G</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1266"/>
        <source>G♯</source>
        <translation>G♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1267"/>
        <location filename="../pianoscene.cpp" line="1280"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1268"/>
        <source>A♯</source>
        <translation>A♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1269"/>
        <location filename="../pianoscene.cpp" line="1282"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1272"/>
        <source>D♭</source>
        <translation>D♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1274"/>
        <source>E♭</source>
        <translation>E♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1277"/>
        <source>G♭</source>
        <translation>G♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1279"/>
        <source>A♭</source>
        <translation>A♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1281"/>
        <source>B♭</source>
        <translation>B♭</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::SonivoxSettingsDialog</name>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="20"/>
        <source>Sonivox EAS Synth</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="107"/>
        <source>Chorus</source>
        <translation>合唱（Chorus）</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="97"/>
        <source>Reverb</source>
        <translation>混响（Reverb）</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="32"/>
        <source>SoundFont:</source>
        <translation>音色库：</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="58"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="75"/>
        <source>Sonivox Library Version:</source>
        <translation>Sonivox 库版本：</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="208"/>
        <source>Buffer Time:</source>
        <translation>缓冲时间：</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="218"/>
        <source> ms</source>
        <translation> 毫秒</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="168"/>
        <source>Init. Status:</source>
        <translation>初始化状态：</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="92"/>
        <source>Sonivox Initialized</source>
        <translation>Sonivox 已初始化</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="92"/>
        <source>Sonivox Initialization Failed</source>
        <translation>Sonivox 初始化失败</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="178"/>
        <source>Ready</source>
        <translation>就绪</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="178"/>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="200"/>
        <source>Select SoundFont</source>
        <translation>选择音色库</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="200"/>
        <source>SoundFont Files (*.dls)</source>
        <translation>音色库文件 (*.dls)</translation>
    </message>
</context>
</TS>
